use nalgebra::Vector4;
use rhai::{CustomType, TypeBuilder};

#[derive(Debug, Clone)]
pub struct Color {
	val: Vector4<f32>,
}

impl Color {
	pub fn new(r: f32, g: f32, b: f32, a: f32) -> Self {
		Self {
			val: Vector4::new(
				r.clamp(0.0, 1.0),
				g.clamp(0.0, 1.0),
				b.clamp(0.0, 1.0),
				a.clamp(0.0, 1.0),
			),
		}
	}

	pub fn as_array(&self) -> [f32; 4] {
		[self.val.x, self.val.y, self.val.z, self.val.w]
	}

	pub fn as_array_u8(&self) -> [u8; 4] {
		let val = self.val * 255.0;
		[val.x as u8, val.y as u8, val.z as u8, val.w as u8]
	}
}

impl CustomType for Color {
	fn build(mut builder: TypeBuilder<Self>) {
		builder.with_name("Color").with_fn("Color", Self::new);
	}
}
